@@ -20,24 +20,23 @@ from __future__ import annotations
 import json
 import warnings
 from time import sleep
-from typing import Any, Callable
+from typing import Any
 
 from botocore.exceptions import ClientError
 
-from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException, AirflowNotFoundException
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
-from airflow.providers.amazon.aws.utils.waiter import get_state, waiter
 from airflow.utils.helpers import prune_dict
 
 
 class EmrHook(AwsBaseHook):
     """
-    Interact with Amazon Elastic MapReduce Service.
+    Interact with Amazon Elastic MapReduce Service (EMR).
+    Provide thick wrapper around :external+boto3:py:class:`boto3.client("emr") <EMR.Client>`.
 
     :param emr_conn_id: :ref:`Amazon Elastic MapReduce Connection <howto/connection:emr>`.
         This attribute is only necessary when using
-        the :meth:`~airflow.providers.amazon.aws.hooks.emr.EmrHook.create_job_flow` method.
+        the :meth:`airflow.providers.amazon.aws.hooks.emr.EmrHook.create_job_flow`.
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
@@ -61,6 +60,9 @@ class EmrHook(AwsBaseHook):
         Fetch id of EMR cluster with given name and (optional) states.
         Will return only if single id is found.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EMR.Client.list_clusters`
+
         :param emr_cluster_name: Name of a cluster to find
         :param cluster_states: State(s) of cluster to find
         :return: id of the EMR cluster
@@ -85,18 +87,21 @@ class EmrHook(AwsBaseHook):
         """
         Create and start running a new cluster (job flow).
 
+        .. seealso::
+            - :external+boto3:py:meth:`EMR.Client.run_job_flow`
+
         This method uses ``EmrHook.emr_conn_id`` to receive the initial Amazon EMR cluster configuration.
         If ``EmrHook.emr_conn_id`` is empty or the connection does not exist, then an empty initial
         configuration is used.
 
         :param job_flow_overrides: Is used to overwrite the parameters in the initial Amazon EMR configuration
-            cluster. The resulting configuration will be used in the boto3 emr client run_job_flow method.
+            cluster. The resulting configuration will be used in the
+            :external+boto3:py:meth:`EMR.Client.run_job_flow`.
 
         .. seealso::
             - :ref:`Amazon Elastic MapReduce Connection <howto/connection:emr>`
+            - :external+boto3:py:meth:`EMR.Client.run_job_flow`
             - `API RunJobFlow <https://docs.aws.amazon.com/emr/latest/APIReference/API_RunJobFlow.html>`_
-            - `boto3 emr client run_job_flow method <https://boto3.amazonaws.com/v1/documentation/\
-               api/latest/reference/services/emr.html#EMR.Client.run_job_flow>`_.
         """
         config = {}
         if self.emr_conn_id:
@@ -138,6 +143,9 @@ class EmrHook(AwsBaseHook):
         """
         Add new steps to a running cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EMR.Client.add_job_flow_steps`
+
         :param job_flow_id: The id of the job flow to which the steps are being added
         :param steps: A list of the steps to be executed by the job flow
         :param wait_for_completion: If True, wait for the steps to be completed. Default is False
@@ -173,6 +181,7 @@ class EmrHook(AwsBaseHook):
         """
         Return failed state for test Amazon Elastic MapReduce Connection (untestable).
 
+
         We need to overwrite this method because this hook is based on
         :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsGenericHook`,
         otherwise it will try to test connection to AWS STS by using the default boto3 credential strategy.
@@ -220,13 +229,14 @@ class EmrHook(AwsBaseHook):
 
 class EmrServerlessHook(AwsBaseHook):
     """
-    Interact with EMR Serverless API.
+    Interact with Amazon EMR Serverless.
+    Provide thin wrapper around :py:class:`boto3.client("emr-serverless") <EMRServerless.Client>`.
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
 
     .. seealso::
-        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
+        - :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
     JOB_INTERMEDIATE_STATES = {"PENDING", "RUNNING", "SCHEDULED", "SUBMITTED"}
@@ -242,78 +252,55 @@ class EmrServerlessHook(AwsBaseHook):
         kwargs["client_type"] = "emr-serverless"
         super().__init__(*args, **kwargs)
 
-    @cached_property
-    def conn(self):
-        """Get the underlying boto3 EmrServerlessAPIService client (cached)"""
-        return super().conn
-
-    # This method should be replaced with boto waiters which would implement timeouts and backoff nicely.
-    def waiter(
-        self,
-        get_state_callable: Callable,
-        get_state_args: dict,
-        parse_response: list,
-        desired_state: set,
-        failure_states: set,
-        object_type: str,
-        action: str,
-        countdown: int = 25 * 60,
-        check_interval_seconds: int = 60,
-    ) -> None:
+    def cancel_running_jobs(self, application_id: str, waiter_config: dict = {}):
         """
-        Will run the sensor until it turns True.
-
-        :param get_state_callable: A callable to run until it returns True
-        :param get_state_args: Arguments to pass to get_state_callable
-        :param parse_response: Dictionary keys to extract state from response of get_state_callable
-        :param desired_state: Wait until the getter returns this value
-        :param failure_states: A set of states which indicate failure and should throw an
-            exception if any are reached before the desired_state
-        :param object_type: Used for the reporting string. What are you waiting for? (application, job, etc)
-        :param action: Used for the reporting string. What action are you waiting for? (created, deleted, etc)
-        :param countdown: Total amount of time the waiter should wait for the desired state
-            before timing out (in seconds). Defaults to 25 * 60 seconds.
-        :param check_interval_seconds: Number of seconds waiter should wait before attempting
-            to retry get_state_callable. Defaults to 60 seconds.
+        List all jobs in an intermediate state and cancel them.
+        Then wait for those jobs to reach a terminal state.
+        Note: if new jobs are triggered while this operation is ongoing,
+        it's going to time out and return an error.
         """
-        warnings.warn(
-            """This method is deprecated.
-            Please use `airflow.providers.amazon.aws.utils.waiter.waiter`.""",
-            DeprecationWarning,
-            stacklevel=2,
+        paginator = self.conn.get_paginator("list_job_runs")
+        results_per_response = 50
+        iterator = paginator.paginate(
+            applicationId=application_id,
+            states=list(self.JOB_INTERMEDIATE_STATES),
+            PaginationConfig={
+                "PageSize": results_per_response,
+            },
         )
-        waiter(
-            get_state_callable=get_state_callable,
-            get_state_args=get_state_args,
-            parse_response=parse_response,
-            desired_state=desired_state,
-            failure_states=failure_states,
-            object_type=object_type,
-            action=action,
-            countdown=countdown,
-            check_interval_seconds=check_interval_seconds,
-        )
-
-    def get_state(self, response, keys) -> str:
-        warnings.warn(
-            """This method is deprecated.
-            Please use `airflow.providers.amazon.aws.utils.waiter.get_state`.""",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return get_state(response=response, keys=keys)
+        count = 0
+        for r in iterator:
+            job_ids = [jr["id"] for jr in r["jobRuns"]]
+            count += len(job_ids)
+            if len(job_ids) > 0:
+                self.log.info(
+                    "Cancelling %s pending job(s) for the application %s so that it can be stopped",
+                    len(job_ids),
+                    application_id,
+                )
+                for job_id in job_ids:
+                    self.conn.cancel_job_run(applicationId=application_id, jobRunId=job_id)
+        if count > 0:
+            self.log.info("now waiting for the %s cancelled job(s) to terminate", count)
+            self.get_waiter("no_job_running").wait(
+                applicationId=application_id,
+                states=list(self.JOB_INTERMEDIATE_STATES.union({"CANCELLING"})),
+                WaiterConfig=waiter_config,
+            )
 
 
 class EmrContainerHook(AwsBaseHook):
     """
-    Interact with AWS EMR Virtual Cluster to run, poll jobs and return job status
+    Interact with Amazon EMR Containers (Amazon EMR on EKS).
+    Provide thick wrapper around :py:class:`boto3.client("emr-containers") <EMRContainers.Client>`.
+
+    :param virtual_cluster_id: Cluster ID of the EMR on EKS virtual cluster
+
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
 
     .. seealso::
-        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
-
-    :param virtual_cluster_id: Cluster ID of the EMR on EKS virtual cluster
+        - :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
     INTERMEDIATE_STATES = (
@@ -378,7 +365,9 @@ class EmrContainerHook(AwsBaseHook):
         Submit a job to the EMR Containers API and return the job ID.
         A job run is a unit of work, such as a Spark jar, PySpark script,
         or SparkSQL query, that you submit to Amazon EMR on EKS.
-        See: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Client.start_job_run
+
+        .. seealso::
+            - :external+boto3:py:meth:`EMRContainers.Client.start_job_run`
 
         :param name: The name of the job run.
         :param execution_role_arn: The IAM role ARN associated with the job run.
@@ -389,8 +378,8 @@ class EmrContainerHook(AwsBaseHook):
         :param client_request_token: The client idempotency token of the job run request.
             Use this if you want to specify a unique ID to prevent two jobs from getting started.
         :param tags: The tags assigned to job runs.
-        :return: Job ID
-        """  # noqa: E501
+        :return: The ID of the job run request.
+        """
         params = {
             "name": name,
             "virtualClusterId": self.virtual_cluster_id,
@@ -419,11 +408,12 @@ class EmrContainerHook(AwsBaseHook):
         """
         Fetch the reason for a job failure (e.g. error message). Returns None or reason string.
 
-        :param job_id: Id of submitted job run
-        :return: str
+        .. seealso::
+            - :external+boto3:py:meth:`EMRContainers.Client.describe_job_run`
+
+        :param job_id: The ID of the job run request.
         """
-        # We absorb any errors if we can't retrieve the job status
-        reason = None
+        reason = None  # We absorb any errors if we can't retrieve the job status
 
         try:
             response = self.conn.describe_job_run(
@@ -444,11 +434,11 @@ class EmrContainerHook(AwsBaseHook):
         """
         Fetch the status of submitted job run. Returns None or one of valid query states.
 
-        See: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run
+        .. seealso::
+            - :external+boto3:py:meth:`EMRContainers.Client.describe_job_run`
 
-        :param job_id: Id of submitted job run
-        :return: str
-        """  # noqa: E501
+        :param job_id: The ID of the job run request.
+        """
         try:
             response = self.conn.describe_job_run(
                 virtualClusterId=self.virtual_cluster_id,
@@ -466,7 +456,6 @@ class EmrContainerHook(AwsBaseHook):
     def poll_query_status(
         self,
         job_id: str,
-        max_tries: int | None = None,
         poll_interval: int = 30,
         max_polling_attempts: int | None = None,
     ) -> str | None:
@@ -474,24 +463,10 @@ class EmrContainerHook(AwsBaseHook):
         Poll the status of submitted job run until query state reaches final state.
         Returns one of the final states.
 
-        :param job_id: Id of submitted job run
-        :param max_tries: Deprecated - Use max_polling_attempts instead
+        :param job_id: The ID of the job run request.
         :param poll_interval: Time (in seconds) to wait between calls to check query status on EMR
         :param max_polling_attempts: Number of times to poll for query state before function exits
-        :return: str
         """
-        if max_tries:
-            warnings.warn(
-                f"Method `{self.__class__.__name__}.max_tries` is deprecated and will be removed "
-                "in a future release.  Please use method `max_polling_attempts` instead.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            if max_polling_attempts and max_polling_attempts != max_tries:
-                raise Exception("max_polling_attempts must be the same value as max_tries")
-            else:
-                max_polling_attempts = max_tries
-
         try_number = 1
         final_query_state = None  # Query state when query reaches final state or max_polling_attempts reached
 
@@ -518,8 +493,10 @@ class EmrContainerHook(AwsBaseHook):
         """
         Cancel the submitted job_run
 
-        :param job_id: Id of submitted job_run
-        :return: dict
+        .. seealso::
+            - :external+boto3:py:meth:`EMRContainers.Client.cancel_job_run`
+
+        :param job_id: The ID of the job run to cancel.
         """
         return self.conn.cancel_job_run(
             virtualClusterId=self.virtual_cluster_id,
