@@ -17,7 +17,6 @@
 # under the License.
 from __future__ import annotations
 
-import warnings
 from typing import TYPE_CHECKING
 
 from airflow.compat.functools import cached_property
@@ -83,7 +82,6 @@ class RedshiftDataOperator(BaseOperator):
         return_sql_result: bool = False,
         aws_conn_id: str = "aws_default",
         region: str | None = None,
-        await_result: bool | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -95,16 +93,7 @@ class RedshiftDataOperator(BaseOperator):
         self.secret_arn = secret_arn
         self.statement_name = statement_name
         self.with_event = with_event
-        self.await_result = await_result
         self.wait_for_completion = wait_for_completion
-        if await_result:
-            warnings.warn(
-                f"Parameter `{self.__class__.__name__}.await_result` is deprecated and will be removed "
-                "in a future release. Please use method `wait_for_completion` instead.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            self.wait_for_completion = await_result
         if poll_interval > 0:
             self.poll_interval = poll_interval
         else:
@@ -122,57 +111,6 @@ class RedshiftDataOperator(BaseOperator):
         """Create and return an RedshiftDataHook."""
         return RedshiftDataHook(aws_conn_id=self.aws_conn_id, region_name=self.region)
 
-    def execute_query(self) -> str:
-        warnings.warn(
-            "This method is deprecated and has been moved to the hook "
-            "`airflow.providers.amazon.aws.hooks.redshift_data.RedshiftDataHook`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        self.statement_id = self.hook.execute_query(
-            database=self.database,
-            sql=self.sql,
-            cluster_identifier=self.cluster_identifier,
-            db_user=self.db_user,
-            parameters=self.parameters,
-            secret_arn=self.secret_arn,
-            statement_name=self.statement_name,
-            with_event=self.with_event,
-            wait_for_completion=self.wait_for_completion,
-            poll_interval=self.poll_interval,
-        )
-        return self.statement_id
-
-    def execute_batch_query(self) -> str:
-        warnings.warn(
-            "This method is deprecated and has been moved to the hook "
-            "`airflow.providers.amazon.aws.hooks.redshift_data.RedshiftDataHook`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        self.statement_id = self.hook.execute_query(
-            database=self.database,
-            sql=self.sql,
-            cluster_identifier=self.cluster_identifier,
-            db_user=self.db_user,
-            parameters=self.parameters,
-            secret_arn=self.secret_arn,
-            statement_name=self.statement_name,
-            with_event=self.with_event,
-            wait_for_completion=self.wait_for_completion,
-            poll_interval=self.poll_interval,
-        )
-        return self.statement_id
-
-    def wait_for_results(self, statement_id: str):
-        warnings.warn(
-            "This method is deprecated and has been moved to the hook "
-            "`airflow.providers.amazon.aws.hooks.redshift_data.RedshiftDataHook`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.hook.wait_for_results(statement_id=statement_id, poll_interval=self.poll_interval)
-
     def execute(self, context: Context) -> GetStatementResultResponseTypeDef | str:
         """Execute a statement against Amazon Redshift"""
         self.log.info("Executing statement: %s", self.sql)
