@@ -18,7 +18,6 @@
 from __future__ import annotations
 
 import json
-import warnings
 from typing import TYPE_CHECKING, Any, Iterable, Sequence, cast
 
 from bson import json_util
@@ -31,11 +30,6 @@ if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-_DEPRECATION_MSG = (
-    "The s3_conn_id parameter has been deprecated. You should pass instead the aws_conn_id parameter."
-)
-
-
 class MongoToS3Operator(BaseOperator):
     """Operator meant to move data from mongo via pymongo to s3 via boto.
 
@@ -59,16 +53,15 @@ class MongoToS3Operator(BaseOperator):
     :param compression: type of compression to use for output file in S3. Currently only gzip is supported.
     """
 
-    template_fields: Sequence[str] = ('s3_bucket', 's3_key', 'mongo_query', 'mongo_collection')
-    ui_color = '#589636'
+    template_fields: Sequence[str] = ("s3_bucket", "s3_key", "mongo_query", "mongo_collection")
+    ui_color = "#589636"
     template_fields_renderers = {"mongo_query": "json"}
 
     def __init__(
         self,
         *,
-        s3_conn_id: str | None = None,
-        mongo_conn_id: str = 'mongo_default',
-        aws_conn_id: str = 'aws_default',
+        mongo_conn_id: str = "mongo_default",
+        aws_conn_id: str = "aws_default",
         mongo_collection: str,
         mongo_query: list | dict,
         s3_bucket: str,
@@ -81,10 +74,6 @@ class MongoToS3Operator(BaseOperator):
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
-        if s3_conn_id:
-            warnings.warn(_DEPRECATION_MSG, DeprecationWarning, stacklevel=3)
-            aws_conn_id = s3_conn_id
-
         self.mongo_conn_id = mongo_conn_id
         self.aws_conn_id = aws_conn_id
         self.mongo_db = mongo_db
@@ -134,7 +123,7 @@ class MongoToS3Operator(BaseOperator):
         )
 
     @staticmethod
-    def _stringify(iterable: Iterable, joinable: str = '\n') -> str:
+    def _stringify(iterable: Iterable, joinable: str = "\n") -> str:
         """
         Takes an iterable (pymongo Cursor or Array) containing dictionaries and
         returns a stringified version using python join
